//! WebUI Zig - Minimal Example
const webui = @import("webui");
const std = @import("std");

pub fn main() !void {
    const window = webui.newWindow();

    // Bind all events
    _ = try window.bind("", events);

    const port = 8080;
    const pathToRootPage = "/home/cholli/projects/website/src/server/";

    webui.setPort(window, port) catch |err| {
        std.debug.print("Could not reserve port {d} due to {any}", .{ port, err });
        webui.exit();
        return;
    };

    _ = webui.startServer(window, pathToRootPage) catch |err| {
        std.debug.print("Could not start server due to: {any}", .{err});
        webui.exit();
        return;
    };

    // wait the window exit
    webui.wait();
}

fn events(e: *webui.Event) void {
    // This function gets called every time
    // there is an event

    switch (e.event_type) {
        .EVENT_CONNECTED => {
            std.debug.print("Connected. \n", .{});
        },
        .EVENT_DISCONNECTED => {
            std.debug.print("Disconnected. \n", .{});
        },
        .EVENT_MOUSE_CLICK => {
            std.debug.print("Click. \n", .{});
        },
        .EVENT_NAVIGATION => {

            // get the url string
            const url = e.getString();

            // we use this to get widnow
            var win = e.getWindow();

            std.debug.print("Starting navigation to: {s}\n", .{url});

            // Because we used `bind(MyWindow, "", events);`
            // WebUI will block all `href` link clicks and sent here instead.
            // We can then control the behaviour of links as needed.

            win.navigate(url);
        },
        else => {},
    }
}
